@@ -1,11 +1,11 @@
 #
-# $Id: Metabrik.pm,v 5ebffa81df72 2015/10/08 14:40:32 gomor $
+# $Id: Metabrik.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use base qw(Class::Gomor::Hash);
 
@@ -28,9 +28,29 @@ sub brik_version {
    return $VERSION.'.'.$revision;
 }
 
+sub brik_author {
+   my $self = shift;
+
+   my $author = $self->brik_properties->{author};
+
+   # Default to GomoR
+   return $author || 'GomoR <GomoR[at]metabrik.org>';
+}
+
+sub brik_license {
+   my $self = shift;
+
+   my $license = $self->brik_properties->{license};
+
+   # Default to BSD 3-Clause
+   return $license || 'http://opensource.org/licenses/BSD-3-Clause';
+}
+
 sub brik_properties {
    return {
-      revision => '$Revision: 5ebffa81df72 $',
+      revision => '$Revision: 647ee0932767 $',
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       tags => [ qw() ],
       attributes => {
          debug => [ qw(0|1) ],
@@ -46,6 +66,8 @@ sub brik_properties {
       },
       commands => {
          brik_version => [ ],
+         brik_author => [ ],
+         brik_license => [ ],
          brik_help_set => [ qw(Attribute) ],
          brik_help_run => [ qw(Command) ],
          brik_class => [ ],
@@ -72,10 +94,14 @@ sub brik_properties {
          brik_check_require_used => [ ],
          brik_check_require_binaries => [ ],
          brik_check_properties => [ ],
+         brik_has_binary => [ qw(binary) ],
+         brik_has_module => [ qw(module) ],
       },
       require_modules => { },
+      optional_modules => { },
       require_used => { },
       require_binaries => { },
+      optional_binaries => { },
    };
 }
 
@@ -275,13 +301,17 @@ sub brik_check_properties {
    # Check all keys are valid
    my %valid_keys = (
       revision => 1,
+      author => 1,
+      license => 1,
       tags => 1,
       attributes => 1,
       attributes_default => 1,
       commands => 1,
       require_modules => 1,
+      optional_modules => 1,
       require_used => 1,
       require_binaries => 1,
+      optional_binaries => 1,
    );
    for my $key (keys %$properties) {
       if (! exists($valid_keys{$key})) {
@@ -292,7 +322,7 @@ sub brik_check_properties {
          print("[-] brik_check_properties: brik_properties with key [$key] is not an ARRAYREF\n");
          $error++;
       }
-      elsif ($key ne 'revision' && $key ne 'tags' && ref($properties->{$key}) ne 'HASH') {
+      elsif ($key ne 'revision' && $key ne 'author' && $key ne 'license' && $key ne 'tags' && ref($properties->{$key}) ne 'HASH') {
          print("[-] brik_check_properties: brik_properties with key [$key] is not a HASHREF\n");
          $error++;
       }
@@ -306,7 +336,7 @@ sub brik_check_properties {
          print("[-] brik_check_properties: brik_use_properties with key [$key] is not an ARRAYREF\n");
          $error++;
       }
-      elsif ($key ne 'revision' && $key ne 'tags' && ref($use_properties->{$key}) ne 'HASH') {
+      elsif ($key ne 'revision' && $key ne 'author' && $key ne 'license' && $key ne 'tags' && ref($use_properties->{$key}) ne 'HASH') {
          print("[-] brik_check_properties: brik_use_properties with key [$key] is not a HASHREF\n");
          $error++;
       }
@@ -314,7 +344,7 @@ sub brik_check_properties {
 
    # Check HASHREFs contains pointers to ARRAYREFs
    for my $key (keys %$properties) {
-      next if ($key eq 'revision' || $key eq 'tags' || $key eq 'attributes_default');
+      next if ($key eq 'revision' || $key eq 'author' || $key eq 'license' || $key eq 'tags' || $key eq 'attributes_default');
 
       for my $subkey (keys %{$properties->{$key}}) {
          if (ref($properties->{$key}->{$subkey}) ne 'ARRAY') {
@@ -324,7 +354,7 @@ sub brik_check_properties {
       }
    }
    for my $key (keys %$use_properties) {
-      next if ($key eq 'revision' || $key eq 'tags' || $key eq 'attributes_default');
+      next if ($key eq 'revision' || $key eq 'author' || $key eq 'license' || $key eq 'tags' || $key eq 'attributes_default');
 
       for my $subkey (keys %{$use_properties->{$key}}) {
          if (ref($use_properties->{$key}->{$subkey}) ne 'ARRAY') {
@@ -368,13 +398,17 @@ sub brik_check_use_properties {
    # Check all keys are valid
    my %valid_keys = (
       revision => 1,
+      author => 1,
+      license => 1,
       tags => 1,
       attributes => 1,
       attributes_default => 1,
       commands => 1,
       require_modules => 1,
+      optional_modules => 1,
       require_used => 1,
       require_binaries => 1,
+      optional_binaries => 1,
    );
    for my $key (keys %$use_properties) {
       if (! exists($valid_keys{$key})) {
@@ -385,7 +419,7 @@ sub brik_check_use_properties {
          print("[-] brik_check_use_properties: brik_use_properties with key [$key] is not an ARRAYREF\n");
          $error++;
       }
-      elsif ($key ne 'revision' && $key ne 'tags' && ref($use_properties->{$key}) ne 'HASH') {
+      elsif ($key ne 'revision' && $key ne 'author' && $key ne 'license' && $key ne 'tags' && ref($use_properties->{$key}) ne 'HASH') {
          print("[-] brik_check_use_properties: brik_use_properties with key [$key] is not a HASHREF\n");
          $error++;
       }
@@ -393,7 +427,7 @@ sub brik_check_use_properties {
 
    # Check HASHREFs contains pointers to ARRAYREFs
    for my $key (keys %$use_properties) {
-      next if ($key eq 'revision' || $key eq 'tags' || $key eq 'attributes_default');
+      next if ($key eq 'revision' || $key ne 'author' && $key ne 'license' || $key eq 'tags' || $key eq 'attributes_default');
 
       for my $subkey (keys %{$use_properties->{$key}}) {
          if (ref($use_properties->{$key}->{$subkey}) ne 'ARRAY') {
@@ -753,7 +787,12 @@ sub brik_tags {
 
    my $tags = $self->brik_properties->{tags};
 
-   return [ sort { $a cmp $b } @$tags ];
+   my $brik_name = $self->brik_name;
+   my @auto_tags = split(/::/, $brik_name);
+
+   my %uniq = map { $_ => 1 } (@auto_tags, @$tags);
+
+   return [ sort { $a cmp $b } keys %uniq ];
 }
 
 sub brik_has_tag {
@@ -761,7 +800,7 @@ sub brik_has_tag {
    my ($tag) = @_;
 
    if (! defined($tag)) {
-      return $self->_log_info($self->brik_help_run('brik_has_tag'));
+      return $self->_log_error($self->brik_help_run('brik_has_tag'));
    }
 
    my %h = map { $_ => 1 } @{$self->brik_tags};
@@ -875,7 +914,7 @@ sub brik_has_command {
    my ($command) = @_;
 
    if (! defined($command)) {
-      return $self->_log_info($self->brik_help_run('brik_has_command'));
+      return $self->_log_error($self->brik_help_run('brik_has_command'));
    }
 
    if (exists($self->brik_commands->{$command})) {
@@ -973,7 +1012,7 @@ sub brik_has_attribute {
    my ($attribute) = @_;
 
    if (! defined($attribute)) {
-      return $self->_log_info($self->brik_help_run('brik_has_attribute'));
+      return $self->_log_error($self->brik_help_run('brik_has_attribute'));
    }
 
    if (exists($self->brik_attributes->{$attribute})) {
@@ -983,6 +1022,40 @@ sub brik_has_attribute {
    return 0;
 }
 
+sub brik_has_module {
+   my $self = shift;
+   my ($module) = @_;
+
+   if (! defined($module)) {
+      return $self->_log_error($self->brik_help_run('brik_has_module'));
+   }
+
+   eval("require $module;");
+   if ($@) {
+      return 0;
+   }
+
+   return 1;
+}
+
+sub brik_has_binary {
+   my $self = shift;
+   my ($binary) = @_;
+
+   if (! defined($binary)) {
+      return $self->_log_error($self->brik_help_run('brik_has_binary'));
+   }
+
+   my @path = split(':', $ENV{PATH});
+   for my $path (@path) {
+      if (-f "$path/$binary") {
+         return 1;
+      }
+   }
+
+   return 0;
+}
+
 # brik_preinit() directly runs after new() is run. new() is called on use().
 sub brik_preinit {
    my $self = shift;
@@ -1030,19 +1103,14 @@ sub brik_self {
    return $self;
 }
 
-# fini() is run at DESTROY time
+# brik_fini Command is run when core::shell run_exit Command is called
+# It itselves call core::context brik_fini Command which loops over all used Briks
 sub brik_fini {
    my $self = shift;
 
    return $self;
 }
 
-sub DESTROY {
-   my $self = shift;
-
-   return $self->brik_fini(@_);
-}
-
 1;
 
 __END__
