@@ -1,17 +1,17 @@
 #
-# $Id: Context.pm,v 519956f054f8 2015/10/17 10:48:12 gomor $
+# $Id: Context.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 519956f054f8 $',
+      revision => '$Revision: 647ee0932767 $',
       tags => [ qw(core context main) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
@@ -29,6 +29,7 @@ sub brik_properties {
          available => [ ],
          is_available => [ qw(Brik) ],
          used => [ ],
+         get_used => [ qw(Brik) ],
          is_used => [ qw(Brik) ],
          not_used => [ ],
          is_not_used => [ qw(Brik) ],
@@ -492,6 +493,24 @@ sub used {
    return $r;
 }
 
+sub get_used {
+   my $self = shift;
+   my ($brik) = @_;
+
+   if (! defined($brik)) {
+      return $self->log->error($self->brik_help_run('get_used'));
+   }
+
+   my $used = $self->used;
+
+   my $get = $used->{$brik};
+   if (! defined($get)) {
+      return $self->log->error("get_used: Brik [$brik] not used");
+   }
+
+   return $get;
+}
+
 sub is_used {
    my $self = shift;
    my ($brik) = @_;
@@ -828,6 +847,18 @@ sub restore_state {
    return $r;
 }
 
+sub brik_fini {
+   my $self = shift;
+
+   my $used = $self->used;
+   for my $brik (keys %$used) {
+      next if $brik eq 'core::context'; # Avoid recursive loop
+      $used->{$brik}->brik_fini;
+   }
+
+   return 1;
+}
+
 1;
 
 __END__
