@@ -1,5 +1,5 @@
 #
-# $Id: Log.pm,v 8fbdfe75bdea 2015/10/02 06:00:00 gomor $
+# $Id: Log.pm,v ff2fda66d776 2015/11/10 09:20:39 gomor $
 #
 # core::log Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Log;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 8fbdfe75bdea $',
+      revision => '$Revision: ff2fda66d776 $',
       tags => [ qw(core main log) ],
       attributes => {
          color => [ qw(0|1) ],
@@ -24,12 +24,12 @@ sub brik_properties {
          level => 1,
       },
       commands => {
-         info => [ qw(string) ],
-         verbose => [ qw(string) ],
-         warning => [ qw(string) ],
-         error => [ qw(string) ],
-         fatal => [ qw(string) ],
-         debug => [ qw(string) ],
+         info => [ qw(string caller|OPTIONAL) ],
+         verbose => [ qw(string caller|OPTIONAL) ],
+         warning => [ qw(string caller|OPTIONAL) ],
+         error => [ qw(string caller|OPTIONAL) ],
+         fatal => [ qw(string caller|OPTIONAL) ],
+         debug => [ qw(string caller|OPTIONAL) ],
       },
       require_modules => {
          'Term::ANSIColor' => [ ],
