@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v 69c83035069a 2015/10/16 17:49:51 gomor $
+# $Id: Shell.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
 #
 # core::shell Brik
 #
@@ -7,7 +7,7 @@ package Metabrik::Core::Shell;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use base qw(Term::Shell Metabrik);
 
@@ -15,7 +15,7 @@ use IO::All;
 
 sub brik_properties {
    return {
-      revision => '$Revision: 69c83035069a $',
+      revision => '$Revision: 647ee0932767 $',
       tags => [ qw(core main shell) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -270,6 +270,20 @@ sub AUTOLOAD {
    return 1;
 }
 
+sub _word_may_be_brik {
+   my $self = shift;
+   my ($word) = @_;
+
+   my $context = $self->context;
+   my $used = $context->used;
+
+   for (keys %$used) {
+      return $used if /^$word/;
+   }
+
+   return 0;
+}
+
 # We overwrite inherited Term::Shell rl_complete() sub to have control
 sub rl_complete {
    my $self = shift;
@@ -277,8 +291,10 @@ sub rl_complete {
 
    my @comp = ();
 
-   # If it's a command, complete 'run_':
-   if ($start == 0 || substr($line, 0, $start) =~ /^\s*$/) {
+   # If it's a command, complete 'run_'.
+   # For that, command must not be blank and not start with '/'.
+   if (($start == 0 || substr($line, 0, $start) =~ /^\s*$/)
+   &&  ($word !~ m{/})) {
       $self->debug && $self->log->debug("rl_complete: word[$word] start[$start] line[$line]");
       @comp = $self->complete('', $word, $line, $start);
 
@@ -296,6 +312,12 @@ sub rl_complete {
             @comp = $self->{_aliases}{"run_$comp[0]"};
          }
       }
+      # Or maybe it's a Brik, and we want to prefix it automagically with 'run' Command
+      elsif (my $available = $self->_word_may_be_brik($word)) {
+         for (keys %$available) {
+            push @comp, "run $_" if /^$word/;
+         }
+      }
    }
    # If it's a subcommand, send it to any custom completion function for the
    # function:
@@ -413,7 +435,7 @@ sub cmd_is_complete {
 
    my $document = PPI::Document->new(\$string);
    if (! $document) {
-      return $self->log->error("cmd_complete: cannot parse Perl string");
+      return $self->log->error("cmd_is_complete: cannot parse Perl string");
    }
 
    # Courtesy of Perl::Shell complete() function
@@ -536,6 +558,9 @@ sub run_exit {
       $context->run('shell::history', 'write');
    } 
 
+   # Global clean-up
+   $context->brik_fini;
+
    return $self->stoploop;
 }
 
@@ -1190,9 +1215,21 @@ sub run_run {
       return $self->log->info("run <brik> <command> [ <arg1> <arg2> .. <argN> ]");
    }
 
-   my $r = $context->run($brik, $command, @args);
-   if (! defined($r)) {
-      return $self->log->error("run: unable to execute Command [$command] for Brik [$brik]");
+   my $r;
+   {
+      local $SIG{INT} = sub {
+         $self->debug && $self->log->debug("run_run: SIG received");
+         if ($self->global->exit_on_sigint) {
+            $self->debug && $self->log->debug("run_run: exiting");
+            $self->run_exit;
+         }
+         die("interrupted by user\n");
+      };
+
+      $r = $context->run($brik, $command, @args);
+      if (! defined($r)) {
+         return $self->log->error("run: unable to execute Command [$command] for Brik [$brik]");
+      }
    }
 
    if ($self->echo) {
@@ -1284,6 +1321,14 @@ sub catch_run {
    my $self = shift;
    my (@args) = @_;
 
+   $self->debug && $self->log->debug("catch_run: args [@args]");
+
+   # If it starts with a '/', we really want to 'run shell::command system'
+   if (defined($args[0]) && $args[0] =~ m{/}) {
+      my $cmd = "run shell::command system";
+      return $self->cmd(join(' ', $cmd, @args));
+   }
+
    # Default to execute Perl commands
    return $self->run_code(@args);
 }
