@@ -1,5 +1,5 @@
 #
-# $Id: Script.pm,v 07f7ae422123 2015/10/09 09:17:45 gomor $
+# $Id: Script.pm,v ff2fda66d776 2015/11/10 09:20:39 gomor $
 #
 # shell::script Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Script;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 07f7ae422123 $',
+      revision => '$Revision: ff2fda66d776 $',
       tags => [ qw(main shell script) ],
       attributes => {
          file => [ qw(file) ],
@@ -43,6 +43,9 @@ sub load {
       or return $self->log->error("load: can't open file [$file]: $!");
    while (defined(my $line = <$in>)) {
       chomp($line);
+      next if $line =~ /^\s*$/;   # Skip blank lines
+      next if $line =~ /^\s*#/;   # Skip comments
+      $line =~ s/^(.*)#.*$/$1/;   # Strip comments at end of line
       push @lines, $line;
    }
    close($in);
